@@ -105,11 +105,6 @@ class AliotObj:
         self.__log = log
         self.__setup_ws(enable_trace)
 
-    def keep_document_live(self, keep_doc_live: bool = True, /):
-        """ Maybe do, maybe don't? """
-        # TODO add or delete a listener on the whole document and keep a local version up to date with it
-        pass
-
     def stop(self):
         if self.__connected and self.__ws:
             self.__ws.close()
